@@ -1,3 +1,5 @@
+"""Constant variables that secure_ec2 use."""
+
 MODULE_NAME = "secure_ec2"
 LAUNCH_TEMPLATE_SUFFIX = "tpl"
 SSM_ROLE_NAME = "SessionManagerInstanceProfile"
@@ -12,3 +14,4 @@ EC2_TRUST_RELATIONSHIP = {
         }
     ],
 }
+LOGGING_FILE_NAME = ".secure_ec2.log"
